@@ -1,9 +1,8 @@
 class Choices:
-    """
-    Helper class to make choices available as class variables, expose a list
-    with valid choices and at the same time generate the choices tuples for
-    the model class.
+    """Helper class to make choices available as class variables.
 
+    It exposes a list with valid choices and at the same time generate the
+    choices tuples forthe model class.
     Usage:
         class MyChoices(Choices):
             ONE = 'one'
@@ -15,13 +14,14 @@ class Choices:
                 max_length=MyChoices.get_max_length(),
                 choices=MyChoices.get_choices(),
             )
-
-    Stolen from bumf (https://github.com/bumfiness/bumf).
     """
+
+    valid_choices = []
+
     @classmethod
     def get_choices(cls):
         return cls.valid_choices
 
     @classmethod
     def get_max_length(cls):
-        return max([len(val) for val, label in cls.valid_choices])
+        return max(len(val) for val, label in cls.valid_choices)
