@@ -11,6 +11,7 @@ from django.http import FileResponse, Http404, JsonResponse
 from django.shortcuts import redirect
 from django.utils.decorators import method_decorator
 from django.utils.functional import cached_property
+from django.utils.timezone import now
 from django.utils.translation import gettext_lazy as _
 from django.views.generic import FormView, TemplateView, UpdateView, View
 from django_context_decorator import context
@@ -28,7 +29,12 @@ from pretalx.common.mixins.views import (
 from pretalx.common.signals import register_data_exporters
 from pretalx.common.utils import safe_filename
 from pretalx.common.views import CreateOrUpdateView
-from pretalx.orga.forms.schedule import ScheduleExportForm, ScheduleReleaseForm
+from pretalx.orga.forms.schedule import (
+    ScheduleExportForm,
+    ScheduleReleaseForm,
+    ScheduleRoomForm,
+    ScheduleVersionForm,
+)
 from pretalx.schedule.forms import QuickScheduleForm, RoomForm
 from pretalx.schedule.models import Availability, Room, TalkSlot
 from pretalx.schedule.utils import guess_schedule_version
@@ -43,6 +49,16 @@ class ScheduleView(EventPermissionRequired, TemplateView):
         result = super().get_context_data(**kwargs)
         version = self.request.GET.get("version")
         result["schedule_version"] = version
+        result["schedule_version_form"] = ScheduleVersionForm(
+            {"version": version} if version else None,
+            event=self.request.event,
+        )
+        result["schedule_room_form"] = ScheduleRoomForm(
+            {"room": self.request.GET.getlist("room")}
+            if "room" in self.request.GET
+            else None,
+            event=self.request.event,
+        )
         result["active_schedule"] = (
             self.request.event.schedules.filter(version=version).first()
             if version
@@ -191,9 +207,10 @@ class ScheduleToggleView(EventPermissionRequired, View):
 
     def dispatch(self, request, event):
         super().dispatch(request, event)
-        self.request.event.settings.set(
-            "show_schedule", not self.request.event.settings.show_schedule
-        )
+        self.request.event.feature_flags[
+            "show_schedule"
+        ] = not self.request.event.feature_flags["show_schedule"]
+        self.request.event.save()
         return redirect(self.request.event.orga_urls.schedule)
 
 
@@ -280,26 +297,31 @@ class TalkList(EventPermissionRequired, View):
             "results": [],
         }
         version = self.request.GET.get("version")
+        schedule = None
         if version:
             schedule = request.event.schedules.filter(version=version).first()
-        else:
+        if not schedule:
             schedule = request.event.wip_schedule
 
         warnings = schedule.get_all_talk_warnings()
-        result["results"] = [
-            serialize_slot(slot, warnings=warnings.get(slot))
-            for slot in (
-                schedule.talks.all()
-                .select_related(
-                    "submission",
-                    "submission__event",
-                    "room",
-                    "submission__submission_type",
-                    "submission__track",
-                )
-                .prefetch_related("submission__speakers")
+        slots = (
+            schedule.talks.all()
+            .select_related(
+                "submission",
+                "submission__event",
+                "room",
+                "submission__submission_type",
+                "submission__track",
             )
+            .prefetch_related("submission__speakers")
+        )
+        filter_updated = request.GET.get("since")
+        if filter_updated:
+            slots = slots.filter(updated__gte=filter_updated)
+        result["results"] = [
+            serialize_slot(slot, warnings=warnings.get(slot)) for slot in slots
         ]
+        result["now"] = now().strftime("%Y-%m-%d %H:%M:%S%z")
         return JsonResponse(result, encoder=I18nJSONEncoder)
 
     def post(self, request, event):
@@ -362,14 +384,17 @@ class TalkUpdate(PermissionRequired, View):
             )
             if not talk.submission:
                 talk.description = LazyI18nString(data.get("description", ""))
-            talk.save(update_fields=["start", "end", "room", "description"])
+            print(talk.updated)
+            talk.save(update_fields=["start", "end", "room", "description", "updated"])
+            talk.refresh_from_db()
+            print(talk.updated)
         else:
             talk.start = None
             talk.end = None
             talk.room = None
-            talk.save(update_fields=["start", "end", "room"])
+            talk.save(update_fields=["start", "end", "room", "updated"])
 
-        with_speakers = self.request.event.settings.cfp_request_availabilities
+        with_speakers = self.request.event.cfp.request_availabilities
         warnings = talk.schedule.get_talk_warnings(talk, with_speakers=with_speakers)
 
         return JsonResponse(serialize_slot(talk, warnings=warnings))
